estimate_heterogeneity: Estimation of between-study heterogeneity

estimate_tau2R Documentation

Estimation of between-study heterogeneity

Description

estimate_tau2 estimates the between-study heterogeneity \tau^{2} using an additive model. The resulting parameter \tau^2 is estimated through a call to meta::metagen with TE = estimates and seTE = SEs. Other arguments to meta::metagen can be passed via the ... argument. If no arguments are passed via ..., the following defaults are applied.

  • sm = "MD"

  • method.tau = "REML"

  • control = list(maxiter = 1e5, stepadj = 0.25)

However, each of these defaults can be overwritten via ....

estimate_phi estimates the between-study heterogeneity \phi using a multiplicative model. The function is a modified version of Page 3 of:
Accounting for heterogeneity in meta-analysis using a multiplicative model – an empirical study, Mawdsley D. et al. 2016. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1002/jrsm.1216")}

Usage

estimate_tau2(estimates, SEs, ...)

estimate_phi(estimates, SEs)

Arguments

estimates

Numeric vector of study-level effect estimates.

SEs

Numeric vector of corresponding standard errors.

...

Further arguments that are passed to meta::metagen().

Value

For estimate_tau2: the estimated heterogeneity parameter \tau^2, a numeric vector of length 1.

For estimate_phi: the estimated heterogeneity parameter \phi, a numeric vector of length 1.

Examples

    # Example estimates and std. errors
    estimates <- c(0.21, 0.53, 0.24, 0.32, 0.19)
    SEs <- c(0.19, 0.39, 0.7, 1, 0.97)

    # Estimating heterogeneity using the additive model
    estimate_tau2(estimates = estimates, SEs = SEs)
    # Example estimates and std. errors
    estimates <- c(0.21, 0.53, 0.24, 0.32, 0.19)
    SEs <- c(0.19, 0.39, 0.7, 1, 0.97)
    
    estimate_phi(estimates = estimates, SEs = SEs)

confMeta documentation built on June 10, 2026, 1:06 a.m.