View source: R/pfun_stouffer.R
| p_stouffer | R Documentation |
Stouffer's method for combining p-values across studies
p_stouffer(
estimates,
SEs,
mu = 0,
heterogeneity = "none",
phi = NULL,
tau2 = NULL,
check_inputs = TRUE,
w = 1/SEs,
output_p = "two.sided"
)
estimates |
Numeric vector of study-level effect estimates. |
SEs |
Numeric vector of corresponding standard errors. |
mu |
Numeric scalar or vector of null values for the overall effect (default: 0). |
heterogeneity |
One of |
phi |
A numeric vector of length 1. Must be finite and larger than 0. The square root of the argument is used to scale the standard errors. |
tau2 |
A numeric vector of length 1. Additive heterogeneity parameter. |
check_inputs |
Either |
w |
Numeric vector of study weights. Defaults to |
output_p |
Character string specifying the combined
p-value type: |
Stouffer's z-statistic for k studies is defined as
z = \frac{\sum_{i=1}^k w_i z_i}{\sqrt{\sum_{i=1}^k w_i^2}},
where z_i and {w_i} are individual study z-values and
weights, respectively. Under the global null hypothesis, each z_i is
assumed to follow a standard normal distribution. Stouffer's z-statistic
then also follows a standard normal distribution. The combined p-value
is calculated as the probability of observing a value equal or greater than
z from this distribution:
p_S = \Pr(Z > z)
A numeric vector of combined p-values corresponding
to each value of mu.
Stouffer SA, et al. The American Soldier. Princeton University Press, 1949. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2307/2572105")}
Held, L, Hofmann, F, Pawel, S. (2025). A comparison of combined p-value functions for meta-analysis. Research Synthesis Methods, 16:758-785. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/rsm.2025.26")}
Other p-value combination functions:
p_edgington(),
p_edgington_w(),
p_fisher(),
p_hmean(),
p_pearson(),
p_tippett(),
p_wilkinson()
estimates <- c(0.1, 0.2, 0.3)
SEs <- c(0.05, 0.05, 0.1)
p_stouffer(estimates, SEs, mu = 0, heterogeneity = "none")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.