| p_value_functions | R Documentation |
The p_value_functions family is useful to combine
individual study effect estimates and standard errors into a single
meta-analytical p-value function. These functions are the
building blocks for the confMeta function.
Vectorization over mu:
All of the p-value functions in this package are vectorized over the
mu argument. This means that you can pass a sequence of null values
(e.g., seq(-2, 2, length.out = 1000)) and the function will
evaluate the combined p-value for every point. This is specifically
designed to construct p-value functions
and invert the tests to find confidence intervals at any desired level.
Available Methods:
p_edgington: Classical Edgington method (Sum of p-values).
p_edgington_w: Weighted Edgington method.
p_fisher: Fisher's method (Log-product of p-values).
p_pearson: Pearson's method (Log-product of complements).
p_tippett: Tippett's method (Minimum p-value).
p_wilkinson: Wilkinson's method (Maximum p-value).
p_stouffer: Stouffer's method.
p_hmean: Harmonic mean method.
Held, L, Hofmann, F, Pawel, S. (2025). A comparison of combined p-value functions for meta-analysis. Research Synthesis Methods, 16:758-785. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1017/rsm.2025.26")}
confMeta
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.